# $XDG_CONFIG_HOME/qutebrowser/config.py
# pyright: basic, reportUnboundVariable = false, reportAttributeAccessIssue = false
# general settings
from typing import Any


config: Any
c: Any
config.load_autoconfig()
c.editor.command = ["footclient", "kak", "{}"]
c.new_instance_open_target = "tab-bg"
# c.input.insert_mode.auto_load = True
c.tabs.background = True
c.content.blocking.enabled = True
c.content.blocking.method = "adblock"
c.auto_save.session = True
c.completion.open_categories = [
    "searchengines",
    "quickmarks",
    "bookmarks",
    "history",
    "filesystem",
]

c.hints.chars = "tnserigmao"

# dark mode
c.colors.webpage.darkmode.enabled = True
c.colors.webpage.darkmode.algorithm = "lightness-cielab"
c.colors.webpage.darkmode.policy.images = "never"
config.set("colors.webpage.darkmode.enabled", False, "file://*")
config.set("colors.webpage.darkmode.enabled", False, "github.com")
c.colors.webpage.preferred_color_scheme = "dark"

# searches
c.url.searchengines["DEFAULT"] = "https://duckduckgo.com/?q={}"
c.url.searchengines["!aw"] = "https://wiki.archlinux.org/?search={}"
c.url.searchengines["!g"] = (
    "http://www.google.com/search?hl=en&source=hp&ie=ISO-8859-l&q={}"
)
c.url.searchengines["ap"] = "https://www.archlinux.org/packages/?sort=&q={}"

# colemak keybindings

config.bind("m", "scroll left", mode="normal")
config.bind("n", "scroll down", mode="normal")
config.bind("e", "scroll up", mode="normal")
config.bind("i", "scroll right", mode="normal")
config.bind("M", "back", mode="normal")
config.bind("N", "tab-next", mode="normal")
config.bind("E", "tab-prev", mode="normal")
config.bind("<Ctrl-i>", "tab-next", mode="normal")
config.bind("<Ctrl-m>", "tab-prev", mode="normal")
config.bind("I", "forward", mode="normal")
config.bind("K", "bookmark-add", mode="normal")
config.bind("k", "quickmark-save", mode="normal")
config.bind("J", "search-prev", mode="normal")
config.bind("j", "search-next", mode="normal")
config.bind("<Ctrl-/>", "hint links spawn --detach mpv {hint-url}")
sets = {
    "normal": [
        ["gm", "tab-focus 1"],
        ["gi", "tab-focus -1"],
        ["gN", "tab-move +"],
        ["gE", "tab-move -"],
        ["gh", "hint inputs --first"],
        ["gk", "tab-move"],
        ["h", "mode-enter insert"],
        ["tm", "back -t"],
        ["ti", "forward -t"],
        # ["v", "save"],
        # ["s", "mode-enter caret"],
        ["wlm", "devtools left"],
        ["wln", "devtools bottom"],
        ["wle", "devtools top"],
        ["wli", "devtools right"],
        ["wm", "back -w"],
        ["wh", "devtools"],
        ["wi", "forward -w"],
    ],
    "caret": [
        ["M", "scroll left"],
        ["N", "scroll down"],
        ["E", "scroll up"],
        ["I", "scroll right"],
        ["l", "move-to-end-of-word"],
        ["m", "move-to-prev-char"],
        ["n", "move-to-next-line"],
        ["e", "move-to-prev-line"],
        ["i", "move-to-next-char"],
    ],
}

for mode, mappings in sets.items():
    for pair in mappings:
        config.bind(pair[0], pair[1], mode=mode)

ashen = {
    "cursorline": "#191919",
    "text": "#b4b4b4",
    "red_flame": "#C53030",
    "red_glowing": "#DF6464",
    "red_ember": "#B14242",
    "orange_glow": "#D87C4A",
    "orange_blaze": "#C4693D",
    "orange_muted": "#6D3B22",
    "orange_smolder": "#E49A44",
    "orange_golden": "#E5A72A",
    "golden_muted": "#6D4D0D",
    "brown": "#89492a",
    "brown_dark": "#322119",
    "brown_darker": "#22150F",
    "blue": "#4A8B8B",
    "background": "#121212",
    "g_1": "#e5e5e5",
    "g_2": "#d5d5d5",
    "g_3": "#b4b4b4",
    "g_4": "#a7a7a7",
    "g_5": "#949494",
    "g_6": "#737373",
    "g_7": "#535353",
    "g_8": "#323232",
    "g_9": "#212121",
    "g_10": "#1d1d1d",
    "g_11": "#191919",
    "g_12": "#151515",
}

# # colors
# c.colors.completion.fg = ashen["text"]
# c.colors.completion.category.fg = "#F2F2F2"
# c.colors.completion.category.bg = "#555555"
# c.colors.completion.item.selected.fg = "white"
# c.colors.completion.item.selected.match.fg = "#0080FF"
# c.colors.completion.item.selected.bg = "#333333"
# c.colors.completion.item.selected.border.top = "#333333"
# c.colors.completion.item.selected.border.bottom = "#333333"
# c.colors.completion.match.fg = "#66FFFF"
# c.colors.statusbar.normal.fg = "#899CA1"
# c.colors.statusbar.normal.bg = "#222222"
# c.colors.statusbar.insert.fg = "#899CA1"
# c.colors.statusbar.insert.bg = "#222222"
# c.colors.statusbar.command.bg = "#555555"
# c.colors.statusbar.command.fg = "#F0F0F0"
# c.colors.statusbar.caret.bg = "#5E468C"
# c.colors.statusbar.caret.selection.fg = "white"
# c.colors.statusbar.progress.bg = "#333333"
# c.colors.statusbar.passthrough.bg = "#4779B3"
# c.colors.statusbar.url.fg = c.colors.statusbar.normal.fg
# c.colors.statusbar.url.success.http.fg = "#899CA1"
# c.colors.statusbar.url.success.https.fg = "#53A6A6"
# c.colors.statusbar.url.error.fg = "#8A2F58"
# c.colors.statusbar.url.warn.fg = "#914E89"
# c.colors.statusbar.url.hover.fg = "#2B7694"
# c.colors.tabs.bar.bg = "#222222"
# c.colors.tabs.even.fg = "#899CA1"
# c.colors.tabs.even.bg = "#222222"
# c.colors.tabs.odd.fg = "#899CA1"
# c.colors.tabs.odd.bg = "#222222"
# c.colors.tabs.selected.even.fg = "white"
# c.colors.tabs.selected.even.bg = "#222222"
# c.colors.tabs.selected.odd.fg = "white"
# c.colors.tabs.selected.odd.bg = "#222222"
# c.colors.tabs.indicator.start = "#222222"
# c.colors.tabs.indicator.stop = "#222222"
# c.colors.tabs.indicator.error = "#8A2F58"
# c.colors.hints.bg = "#CCCCCC"
# c.colors.hints.match.fg = "#000"
# c.colors.downloads.start.fg = "black"
# c.colors.downloads.start.bg = "#BFBFBF"
# c.colors.downloads.stop.fg = "black"
# c.colors.downloads.stop.bg = "#F0F0F0"
# c.colors.keyhint.fg = "#FFFFFF"
# c.colors.keyhint.suffix.fg = "#FFFF00"
# c.colors.keyhint.bg = "rgba(0, 0, 0, 80%)"
# c.colors.messages.error.bg = "#8A2F58"
# c.colors.messages.error.border = "#8A2F58"
# c.colors.messages.warning.bg = "#BF85CC"
# c.colors.messages.warning.border = c.colors.messages.warning.bg
# c.colors.messages.info.bg = "#333333"
# c.colors.prompts.fg = "#333333"
# c.colors.prompts.bg = "#DDDDDD"
# c.colors.prompts.selected.bg = "#4779B3"

config.source("qutebrowser-themes/themes/onedark.py")
